containertools.iterate_containers_forward_in_expr
=================================================

.. autofunction:: abjad.tools.containertools.iterate_containers_forward_in_expr.iterate_containers_forward_in_expr
